elephant.conversion.BinnedSpikeTrain
====================================

.. currentmodule:: elephant.conversion

.. autoclass:: BinnedSpikeTrain
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BinnedSpikeTrain.__init__
      ~BinnedSpikeTrain.binarize
      ~BinnedSpikeTrain.copy
      ~BinnedSpikeTrain.get_num_of_spikes
      ~BinnedSpikeTrain.rescale
      ~BinnedSpikeTrain.time_slice
      ~BinnedSpikeTrain.to_array
      ~BinnedSpikeTrain.to_bool_array
      ~BinnedSpikeTrain.to_sparse_array
      ~BinnedSpikeTrain.to_sparse_bool_array
      ~BinnedSpikeTrain.to_spike_trains
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BinnedSpikeTrain.bin_centers
      ~BinnedSpikeTrain.bin_edges
      ~BinnedSpikeTrain.bin_size
      ~BinnedSpikeTrain.binsize
      ~BinnedSpikeTrain.is_binary
      ~BinnedSpikeTrain.num_bins
      ~BinnedSpikeTrain.shape
      ~BinnedSpikeTrain.sparsity
      ~BinnedSpikeTrain.spike_indices
      ~BinnedSpikeTrain.t_start
      ~BinnedSpikeTrain.t_stop
   
   